betty.test_utils.ancestry.gender module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.ancestry.gender module

Test utilities for `betty.ancestry.gender`.

class betty.test_utils.ancestry.gender.DummyGender

  Bases: `DummyPlugin`, `Gender`

  A dummy gender implementation.

class betty.test_utils.ancestry.gender.GenderTestBase

  Bases: `PluginTestBase`[`Gender`]

  A base class for testing `betty.ancestry.gender.Gender` implementations.